@@ -142,7 +142,7 @@ class ANA():
         ar = ar.reshape((sz, sz)).copy()
         ar[::2] = np.fliplr(ar[::2])
 
-        mSize = self.param.MapSize[spot]
+        mSize = self.param.MapSize[spot-1]
         plt.imshow(ar, origin='bottomleft', extent=(0, mSize, 0, mSize), **kwargs)
         plt.xlabel('[um]')
         plt.ylabel('[um]')
